@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 PySqueezeCenter: Python Wrapper for Logitech SqueezeCenter CLI
 (Telnet) Interface
@@ -31,7 +29,7 @@ class Player(object):
     
     # internals
     
-    def __init__(self, server=None, index=None):
+    def __init__(self, server=None, index=None, update=True):
         """
         Constructor
         """
@@ -67,45 +65,46 @@ class Player(object):
         self.track_remote = None
         self.track_current_title = None
         self.track_path = None
-        self.update(index)
+        self.update(index, update=update)
 
     def __repr__(self):
         return "Player: %s" % (self.ref)
     
-    def request(self, command_string):
+    def request(self, command_string, preserve_encoding=False):
         """Executes Telnet Request via SqueezeCenter"""
-        return self.server.request("%s %s" % (self.ref, command_string))
+        return self.server.request("%s %s" % (self.ref, command_string), preserve_encoding)
     
-    def update(self, index):
+    def update(self, index, update=True):
         """Update Player Properties from SqueezeCenter"""
         self.index = index
         self.ref = str(urllib.unquote(
             self.server.request("player id %i ?" % index)
-        ))
-        self.uuid = str(urllib.unquote(
-            self.server.request("player uuid %i ?" % index)
-        ))
+        ))        
         self.name = str(urllib.unquote(
             self.server.request("player name %i ?" % index)
-        ))    
-        self.ip_address = str(urllib.unquote(
-            self.server.request("player ip %i ?" % index)
-        ))    
-        self.model = str(urllib.unquote(
-            self.server.request("player model %i ?" % index)
-        ))   
-        self.display_type = str(urllib.unquote(
-            self.server.request("player displaytype %i ?" % index)
-        ))
-        self.can_power_off = bool(urllib.unquote(
-            self.server.request("player canpoweroff %i ?" % index)
-        )) 
-        self.is_player = bool(urllib.unquote(
-            self.server.request("player isplayer %i ?" % index)
-        )) 
-        self.is_connected = bool(urllib.unquote(
-            self.server.request("player connected %i ?" % index)
         )) 
+        if update:
+            self.uuid = str(urllib.unquote(
+                self.server.request("player uuid %i ?" % index)
+            ))
+            self.ip_address = str(urllib.unquote(
+                self.server.request("player ip %i ?" % index)
+            ))    
+            self.model = str(urllib.unquote(
+                self.server.request("player model %i ?" % index)
+            ))   
+            self.display_type = str(urllib.unquote(
+                self.server.request("player displaytype %i ?" % index)
+            ))
+            self.can_power_off = bool(urllib.unquote(
+                self.server.request("player canpoweroff %i ?" % index)
+            )) 
+            self.is_player = bool(urllib.unquote(
+                self.server.request("player isplayer %i ?" % index)
+            )) 
+            self.is_connected = bool(urllib.unquote(
+                self.server.request("player connected %i ?" % index)
+            )) 
 
     ## getters/setters
 
@@ -317,6 +316,10 @@ class Player(object):
         """Delete Item From Playlist By Name"""
         item = urllib.quote(item)
         self.request("playlist deleteitem %s" % (item))
+    
+    def playlist_clear(self):
+        """Clear the entire playlist. Will stop the player."""
+	self.request("playlist clear")
 
     def playlist_move(self, from_index, to_index):
         """Move Item In Playlist"""
@@ -326,6 +329,34 @@ class Player(object):
         """Erase Item From Playlist"""
         self.request("playlist delete %i" % (index))
     
+    def playlist_track_count(self):
+        """Get the amount of tracks in the current playlist"""
+	return int(self.request('playlist tracks ?'))
+    
+    def playlist_play_index(self, index):
+        """Play track at a certain position in the current playlist (index is zero-based)"""
+	return self.request('playlist index %i' % index)
+    
+    def playlist_get_info(self):
+        """Get info about the tracks in the current playlist"""
+        amount = self.playlist_track_count()
+        response = self.request('status 0 %i' % amount, True)
+        encoded_list = response.split('playlist%20index')[1:]
+        playlist = []
+        for encoded in encoded_list:
+            data = [urllib.unquote(x) for x in ('position' + encoded).split(' ')]
+            item = {}
+            for info in data:
+                info = info.split(':')
+                key = info.pop(0)
+                if key:
+                    item[key] = ':'.join(info)
+            item['position'] = int(item['position'])
+            item['id'] = int(item['id'])
+            item['duration'] = float(item['duration'])
+            playlist.append(item)
+        return playlist
+    
     # actions
                
     def show(self, line1="", 
