@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 PySqueezeCenter: Python Wrapper for Logitech SqueezeCenter CLI
 (Telnet) Interface
@@ -51,13 +49,13 @@ class Server(object):
         self.player_count = 0
         self.players = []
     
-    def connect(self):
+    def connect(self, update=True):
         """
         Connect
         """
         self.telnet_connect()
         self.login()
-        self.get_players()
+        self.get_players(update=update)
         
     def telnet_connect(self):
         """
@@ -72,13 +70,15 @@ class Server(object):
         result = self.request("login %s %s" % (self.username, self.password))
         self.logged_in = (result == "******")
         
-    def request(self, command_string):
+    def request(self, command_string, preserve_encoding=False):
         """
         Request
         """
         # self.logger.debug("Telnet: %s" % (command_string))
         self.telnet.write(command_string + "\n")
-        response = urllib.unquote(self.telnet.read_until("\n"))[:-1]
+    	response = self.telnet.read_until("\n")[:-1]
+    	if not preserve_encoding:
+	        response = urllib.unquote(response)
         start = command_string.split(" ")[0]
         if start in ["songinfo", "trackstat"]:
             result = response[len(command_string)+1:]
@@ -87,14 +87,14 @@ class Server(object):
         result = result.strip()
         return result
 
-    def get_players(self):
+    def get_players(self, update=True):
         """
         Get Players
         """
         self.players = []
         player_count = self.get_player_count()
         for i in range(player_count):
-            player = Player(server=self, index=i-1)
+            player = Player(server=self, index=i-1, update=update)
             self.players.append(player)
         return self.players
 
